﻿using ProjetBlazor.Components;
using ProjetBlazor.Models;
using ProjetBlazor.Factories;
using ProjetBlazor.Models;
using ProjetBlazor.Services;


namespace Blazor.Services
{
    /// <summary>
    /// Service for interacting with a data API.
    /// </summary>
    public class DataApiService : IDataService
    {
        private readonly HttpClient _http;

        /// <summary>
        /// Constructor for DataApiService.
        /// </summary>
        /// <param name="http">HttpClient for making API requests.</param>
        public DataApiService(HttpClient http)
        {
            _http = http;
        }

        /// <summary>
        /// Get the number of items in the API.
        /// </summary>
        /// <returns>Task representing the asynchronous operation, returning the number of items.</returns>
        public async Task<int> Count()
        {
            return await _http.GetFromJsonAsync<int>("https://localhost:7234/api/Crafting/count");
        }

        /// <summary>
            /// Get a list of items from the API, paginated.
            /// </summary>
            /// <param name="currentPage">The current page number.</param>
            /// <param name="pageSize">The number of items per page.</param>
            /// <returns>Task representing the asynchronous operation, returning a list of items.</returns>
            public async Task<List<Item>> List(int currentPage, int pageSize)
        {
            return await _http.GetFromJsonAsync<List<Item>>($"https://localhost:7234/api/Crafting/?currentPage={currentPage}&pageSize={pageSize}");
        }

        /// <summary>
        /// Get a list of all items from the API.
        /// </summary>
        /// <returns>Task representing the asynchronous operation, returning a list of items.</returns>
        public async Task<List<Item>> GetAll()
        {
            return await _http.GetFromJsonAsync<List<Item>>($"https://localhost:7234/api/Crafting/all");
        }

        /// <summary>
        /// Get a single item from the API by its ID.
        /// </summary>
        /// <param name="id">The ID of the item to retrieve.</param>
        /// <returns>Task representing the asynchronous operation, returning the item with the specified ID.</returns>
        public async Task<Item> GetById(int id)
        {
            return await _http.GetFromJsonAsync<Item>($"https://localhost:7234/api/Crafting/{id}");
        }
    }
}
